package logic

import (
	"fusenapi/constants"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"math"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetDepartmentsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetDepartmentsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetDepartmentsLogic {
	return &GetDepartmentsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *GetDepartmentsLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *GetDepartmentsLogic) GetDepartments(req *types.GetDepartmentsReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	if req.CurrentPage <= 0 {
		req.CurrentPage = constants.DEFAULT_PAGE
	}
	if req.PageSize <= 0 {
		req.PageSize = constants.DEFAULT_PAGE_SIZE
	}
	resList, resTotal, err := l.svcCtx.AllModels.LdapDepartment.GetList(l.ctx, req.CurrentPage, req.PageSize, "")
	if err != nil {
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeDbSqlErr, "获取部门列表失败")
	}
	var pageCount int64 = 1
	if resTotal > int64(req.PageSize) {
		var float64Count = float64(resTotal)
		var float64PerPage = float64(req.PageSize)
		pageCountFloat := math.Ceil(float64Count / float64PerPage)
		pageCount = int64(pageCountFloat)
	}

	return resp.SetStatus(basic.CodeOK, map[string]interface{}{
		"list": resList,
		"meta": map[string]int64{
			"total_count":  resTotal,
			"page_count":   pageCount,
			"current_page": int64(req.CurrentPage),
			"per_page":     int64(req.PageSize),
		},
	})
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *GetDepartmentsLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
